
## load Sebastian Gibb's MALDIquant and MALDIquantForeign libraries
## Gibb S, Strimmer K. MALDIquant: a versatile R package for the analysis of mass spectrometry data. 
## Bioinformatics. 2012 Sep 1;28(17):2270-1. doi:10.1093/bioinformatics/bts447. 
## Epub 2012 Jul 12. PubMed PMID: 22796955.


library("MALDIquant")
library("MALDIquantForeign")
library("vegetarian")
library("pheatmap")
library("colorspace")

## get names of all .mzML files in current working directory

mzML_list<-list.files(pattern="*.mzML")

## Sum all scans of each .mzML file and create list of MassSpectrum objects named spectra

filecounter<-1
spectra<-list()
mzMLno<-length(mzML_list)

while (filecounter<=mzMLno)
{
	mzML_filename<-mzML_list[filecounter]
	print(mzML_filename)
	importspectrum <- import(mzML_filename)
	sumspectrum <- averageMassSpectra(importspectrum, method="sum")
	spectra[[filecounter]]<-sumspectrum
	filecounter<-filecounter+1
}

## Plot all spectra to pdf
## You can plot individual spectra with plot(spectra[[1]])
filecounter<-1
pdf("spectra.pdf")
while (filecounter<=mzMLno)
{
	mzML_filename<-mzML_list[filecounter]
	plot(spectra[[filecounter]])
	filecounter<-filecounter+1
}
dev.off()

## Peak picking

peaks<-detectPeaks(spectra, SNR=5)

## Peak alignment using the warping function of Maldiquant

warpingFunctions<-determineWarpingFunctions(peaks)
peaks<-warpMassPeaks(peaks,warpingFunctions)

## Peak binning and creation of feature matrix
peaks<-binPeaks(peaks)
featureMatrix<-intensityMatrix(peaks)

## Replace NAN values by 0
featureMatrix[is.na(featureMatrix)] <- 0
write.csv(featureMatrix,"featureMatrix_DIESI_Arabidopsis_96h.csv")

## Normalize spectra

normout_featureMatrix<-normalize.rows(featureMatrix)
samplenames<-gsub(".mzML","",mzML_list)
rownames(normout_featureMatrix)<-samplenames
colnames(normout_featureMatrix)<-colnames(featureMatrix)
write.csv(normout_featureMatrix,"normout_featureMatrix_DIESI_Arabidopsis_96h.csv")


## Sort by columns with maxium intensity and eliminate others

#find maximal value for each column (mz-bin)
columnmax<-apply(normout_featureMatrix, 2, max)

#sort and select the 100 most intense values
colmax<-sort(columnmax,decreasing=TRUE)
colmaxselection<-as.matrix(colmax[1:100])
colmaxselection=as.vector(rownames(colmaxselection))

#limiting matrix to selection
max_normout_featureMatrix<-normout_featureMatrix[,colmaxselection]

## Create heatmap

t_max_normout_featureMatrix<-t(max_normout_featureMatrix)
pheatmap(t_max_normout_featureMatrix,scale="row",cluster_cols = TRUE, cluster_rows = FALSE, clustering_distance_rows="euclidean", clustering_distance_cols="euclidean", clustering_methode="complete",cellwidth = 15, cellheight = 9, fontsize=8, color=diverge_hcl(12), filename="metabolic-heatmap.pdf")


## Phylochemical tree based on metabolic fingerprint
library("pvclust")
bootstrapdata <- featureMatrix
#Prepare Data
bootstrapdata <- scale(bootstrapdata) # standardize variables using de normoutputmatrix
rownames(bootstrapdata)<-samplenames

pv2 <- pvclust(t(bootstrapdata),
              method.hclust="ward.D2",
              method.dist="euclidean", nboot = 1000)# other method cluster= "complete"

pdf("bootstrap-dendrogram.pdf")
plot(pv2, print.num=F) # dendogram with p values
# add rectangles around groups highly supported by the data
pvrect(pv2, alpha=.95)
dev.off()

## Plotting example spectra


#tiff(filename="spectrum-with-peaks.tiff", res=1200, compression="lzw", height=200, width=200, units="mm")
#plot(spectra[[1]], xlim=c(40, 800), xlab="m/z", col="red")
#points(peaks[[1]], xlim=c(40, 800), pch=18, col="red")
#plot(spectra[[4]], xlim=c(40, 200), xlab="m/z", col="blue")
#points(peaks[[4]], xlim=c(40, 800), pch=18, col="blue")
#plot(spectra[[7]], xlim=c(40, 200), xlab="m/z", col="green")
#points(peaks[[7]], xlim=c(40, 800), pch=18, col="green")
#dev.off()

